<?php

namespace App\Controllers;

use App\Models\UserModel;
use CodeIgniter\Controller;

class AuthController extends Controller
{
    public function login()
    {
        return view('auth/login');
    }

    public function loginProcess()
    {
        // Ambil session
        $session = session();
        $model = new UserModel();

        // Ambil input dari form login
        $username = $this->request->getVar('username');
        $password = $this->request->getVar('password');

        // Cari user berdasarkan username
        $user = $model->where('username', $username)->first();

        if ($user) {
            // Verifikasi password
            if (password_verify($password, $user['password'])) {
                // Set session data
                $session->set([
                    'id' => $user['id'],
                    'isLoggedIn' => true,
                    'username' => $user['username'],
                    'logged_in' => TRUE
                ]);
                // Redirect ke halaman dashboard
                return redirect()->to('/dashboard');
            } else {
                // Password salah
                $session->setFlashdata('error', 'Password salah');
                return redirect()->to('/login');
            }
        } else {
            // Username tidak ditemukan
            $session->setFlashdata('error', 'Username tidak ditemukan');
            return redirect()->to('/login');
        }
    }

    public function logout()
    {
        $session = session();
        $session->destroy();
        return redirect()->to('/login');
    }

    public function updatePassword()
    {
        // Ambil session
        $session = session();
        $model = new UserModel();

        // Ambil user yang sedang login
        $userId = $session->get('id');
        $user = $model->find($userId);

        // Ambil input dari form
        $old_password = $this->request->getVar('old_password');
        $new_password = $this->request->getVar('new_password');
        $confirm_password = $this->request->getVar('confirm_password');

        // Verifikasi password lama
        if (!password_verify($old_password, $user['password'])) {
            $session->setFlashdata('error', 'Password lama salah');
            return redirect()->to('setting');
        }

        // Cek apakah password baru dan konfirmasi password sesuai
        if ($new_password !== $confirm_password) {
            $session->setFlashdata('error', 'Konfirmasi password tidak cocok');
            return redirect()->to('setting');
        }

        // Update password baru (hash terlebih dahulu)
        $data = [
            'password' => password_hash($new_password, PASSWORD_DEFAULT)
        ];

        $model->update($userId, $data);

        $session->setFlashdata('success', 'Password berhasil diubah');
        return redirect()->to('setting');
    }

}
