<?php

namespace App\Controllers;

use App\Models\KonsumenModel;
use App\Models\SettingModel;

class KirimPesanController extends BaseController
{
    protected $konsumenModel;
    protected $settingModel;

    public function __construct()
    {
        $this->konsumenModel = new KonsumenModel();
        $this->settingModel = new SettingModel();
    }

    // Halaman form kirim pesan
    public function index()
    {
        // Ambil data konsumen dari database
        $data['datakonsumen'] = $this->konsumenModel->findAll();

        // Tampilkan view kirim pesan
        return view('kirim_pesan', $data);
    }

    // Proses pengiriman pesan
    public function send()
    {
        // Ambil data dari form
        $nomor_hp_list = $this->request->getPost('nomor_hp');  // Array nomor HP
        $pesan = $this->request->getPost('pesan');

        // Gunakan helper send_sms untuk mengirim pesan ke setiap nomor
        helper('send_sms_helper');

        // Ambil token dari tabel setting (id = 1)
        $setting = $this->settingModel->find(1);  // Anggap token disimpan di id=1

        // Pastikan token ditemukan
        if (!$setting || empty($setting['token'])) {
            // Set flashdata untuk error
            session()->setFlashdata('error', 'Token tidak ditemukan dalam pengaturan.');
            return redirect()->to('/kirim_pesan');
        }

        // Token dari tabel setting
        $token = $setting['token'];

        // Variabel untuk menampung hasil
        $success_count = 0;
        $fail_count = 0;
        $error_messages = [];

        // Loop untuk mengirim pesan ke setiap nomor HP yang dipilih
        foreach ($nomor_hp_list as $nomor_hp) {
            $response = send_sms($token, $nomor_hp, $pesan);

            if ($response['status'] == 'success') {
                $success_count++;
            } else {
                $fail_count++;
                $error_messages[] = 'Gagal mengirim ke ' . $nomor_hp . ': ' . $response['message'];
            }
        }

        // Buat flashdata untuk pesan sukses atau gagal
        if ($success_count > 0) {
            session()->setFlashdata('success', "$success_count pesan berhasil dikirim.");
        }

        if ($fail_count > 0) {
            session()->setFlashdata('error', implode('<br>', $error_messages));
        }

        // Redirect kembali ke halaman form
        return redirect()->to('/kirim_pesan');
    }
}
